@@ -1334,6 +1334,11 @@ impl DnsMessage {
 
         let mut res = Vec::new();
         for label in domain.split('.') {
+            if label == "" {
+                // TODO currently we don't validate `domain`. If `label` is not the last label,
+                // this condition should signal an error.
+                continue;
+            }
             if label.bytes().len() > 63 {
                 return Err(EncodeError::LabelTooLong(label.bytes().len()));
             }
